@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1999-2009 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 1999-2011 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** All rights reserved.
 **
@@ -48,7 +48,7 @@ typedef	struct
 static void copy_metadata (SNDFILE *outfile, SNDFILE *infile, int channels) ;
 
 static void
-print_usage (char *progname)
+usage_exit (const char *progname)
 {
 	printf ("\nUsage : %s [options] [encoding] <input file> <output file>\n", progname) ;
 	puts ("\n"
@@ -85,21 +85,21 @@ print_usage (char *progname)
 	sfe_dump_format_map () ;
 
 	puts ("") ;
-} /* print_usage */
+	exit (0) ;
+} /* usage_exit */
 
 int
 main (int argc, char * argv [])
-{	char 		*progname, *infilename, *outfilename ;
+{	const char	*progname, *infilename, *outfilename ;
 	SNDFILE	 	*infile = NULL, *outfile = NULL ;
 	SF_INFO	 	sfinfo ;
 	int			k, outfilemajor, outfileminor = 0, infileminor ;
 	int			override_sample_rate = 0 ; /* assume no sample rate override. */
 
-	progname = strrchr (argv [0], '/') ;
-	progname = progname ? progname + 1 : argv [0] ;
+	progname = program_name (argv [0]) ;
 
 	if (argc < 3 || argc > 5)
-	{	print_usage (progname) ;
+	{	usage_exit (progname) ;
 		return 1 ;
 		} ;
 
@@ -108,19 +108,19 @@ main (int argc, char * argv [])
 
 	if (strcmp (infilename, outfilename) == 0)
 	{	printf ("Error : Input and output filenames are the same.\n\n") ;
-		print_usage (progname) ;
+		usage_exit (progname) ;
 		return 1 ;
 		} ;
 
 	if (strlen (infilename) > 1 && infilename [0] == '-')
 	{	printf ("Error : Input filename (%s) looks like an option.\n\n", infilename) ;
-		print_usage (progname) ;
+		usage_exit (progname) ;
 		return 1 ;
 		} ;
 
 	if (outfilename [0] == '-')
 	{	printf ("Error : Output filename (%s) looks like an option.\n\n", outfilename) ;
-		print_usage (progname) ;
+		usage_exit (progname) ;
 		return 1 ;
 		} ;
 
@@ -198,6 +198,8 @@ main (int argc, char * argv [])
 		exit (1) ;
 		} ;
 
+	memset (&sfinfo, 0, sizeof (sfinfo)) ;
+
 	if ((infile = sf_open (infilename, SFM_READ, &sfinfo)) == NULL)
 	{	printf ("Not able to open input file %s.\n", infilename) ;
 		puts (sf_strerror (NULL)) ;
@@ -269,12 +271,12 @@ copy_metadata (SNDFILE *outfile, SNDFILE *infile, int channels)
 {	SF_INSTRUMENT inst ;
 	SF_BROADCAST_INFO_2K binfo ;
 	const char *str ;
-	int k, err = 0, chanmap [256] ;
+	int k, chanmap [256] ;
 
 	for (k = SF_STR_FIRST ; k <= SF_STR_LAST ; k++)
 	{	str = sf_get_string (infile, k) ;
 		if (str != NULL)
-			err = sf_set_string (outfile, k, str) ;
+			sf_set_string (outfile, k, str) ;
 		} ;
 
 	memset (&inst, 0, sizeof (inst)) ;
