@@ -1,5 +1,5 @@
 /*
-** Copyright (C) 1999-2004 Erik de Castro Lopo <erikd@mega-nerd.com>
+** Copyright (C) 1999-2011 Erik de Castro Lopo <erikd@mega-nerd.com>
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU Lesser General Public License as published by
@@ -16,8 +16,11 @@
 ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
+#include	"sfconfig.h"
+
+#include	<math.h>
+
 #include	"sndfile.h"
-#include	"float_cast.h"
 #include	"common.h"
 
 static sf_count_t alaw_read_alaw2s (SF_PRIVATE *psf, short *ptr, sf_count_t len) ;
@@ -25,33 +28,33 @@ static sf_count_t alaw_read_alaw2i (SF_PRIVATE *psf, int *ptr, sf_count_t len) ;
 static sf_count_t alaw_read_alaw2f (SF_PRIVATE *psf, float *ptr, sf_count_t len) ;
 static sf_count_t alaw_read_alaw2d (SF_PRIVATE *psf, double *ptr, sf_count_t len) ;
 
-static sf_count_t alaw_write_s2alaw (SF_PRIVATE *psf, short *ptr, sf_count_t len) ;
-static sf_count_t alaw_write_i2alaw (SF_PRIVATE *psf, int *ptr, sf_count_t len) ;
-static sf_count_t alaw_write_f2alaw (SF_PRIVATE *psf, float *ptr, sf_count_t len) ;
-static sf_count_t alaw_write_d2alaw (SF_PRIVATE *psf, double *ptr, sf_count_t len) ;
+static sf_count_t alaw_write_s2alaw (SF_PRIVATE *psf, const short *ptr, sf_count_t len) ;
+static sf_count_t alaw_write_i2alaw (SF_PRIVATE *psf, const int *ptr, sf_count_t len) ;
+static sf_count_t alaw_write_f2alaw (SF_PRIVATE *psf, const float *ptr, sf_count_t len) ;
+static sf_count_t alaw_write_d2alaw (SF_PRIVATE *psf, const double *ptr, sf_count_t len) ;
 
 static void alaw2s_array (unsigned char *buffer, int count, short *ptr) ;
 static void alaw2i_array (unsigned char *buffer, int count, int *ptr) ;
 static void alaw2f_array (unsigned char *buffer, int count, float *ptr, float normfact) ;
 static void alaw2d_array (unsigned char *buffer, int count, double *ptr, double normfact) ;
 
-static void s2alaw_array (short *buffer, int count, unsigned char *ptr) ;
-static void i2alaw_array (int *buffer, int count, unsigned char *ptr) ;
-static void f2alaw_array (float *buffer, int count, unsigned char *ptr, float normfact) ;
-static void d2alaw_array (double *buffer, int count, unsigned char *ptr, double normfact) ;
+static void s2alaw_array (const short *buffer, int count, unsigned char *ptr) ;
+static void i2alaw_array (const int *buffer, int count, unsigned char *ptr) ;
+static void f2alaw_array (const float *buffer, int count, unsigned char *ptr, float normfact) ;
+static void d2alaw_array (const double *buffer, int count, unsigned char *ptr, double normfact) ;
 
 
 int
 alaw_init (SF_PRIVATE *psf)
 {
-	if (psf->mode == SFM_READ || psf->mode == SFM_RDWR)
+	if (psf->file.mode == SFM_READ || psf->file.mode == SFM_RDWR)
 	{	psf->read_short		= alaw_read_alaw2s ;
 		psf->read_int		= alaw_read_alaw2i ;
 		psf->read_float		= alaw_read_alaw2f ;
 		psf->read_double	= alaw_read_alaw2d ;
 		} ;
 
-	if (psf->mode == SFM_WRITE || psf->mode == SFM_RDWR)
+	if (psf->file.mode == SFM_WRITE || psf->file.mode == SFM_RDWR)
 	{	psf->write_short	= alaw_write_s2alaw ;
 		psf->write_int		= alaw_write_i2alaw ;
 		psf->write_float	= alaw_write_f2alaw ;
@@ -66,7 +69,7 @@ alaw_init (SF_PRIVATE *psf)
 	else
 		psf->datalength = 0 ;
 
-	psf->sf.frames = psf->datalength / psf->blockwidth ;
+	psf->sf.frames = psf->blockwidth > 0 ? psf->datalength / psf->blockwidth : 0 ;
 
 	return 0 ;
 } /* alaw_init */
@@ -311,7 +314,7 @@ alaw2d_array (unsigned char *buffer, int count, double *ptr, double normfact)
 } /* alaw2d_array */
 
 static inline void
-s2alaw_array (short *ptr, int count, unsigned char *buffer)
+s2alaw_array (const short *ptr, int count, unsigned char *buffer)
 {	while (--count >= 0)
 	{	if (ptr [count] >= 0)
 			buffer [count] = alaw_encode [ptr [count] / 16] ;
@@ -321,7 +324,7 @@ s2alaw_array (short *ptr, int count, unsigned char *buffer)
 } /* s2alaw_array */
 
 static inline void
-i2alaw_array (int *ptr, int count, unsigned char *buffer)
+i2alaw_array (const int *ptr, int count, unsigned char *buffer)
 {	while (--count >= 0)
 	{	if (ptr [count] >= 0)
 			buffer [count] = alaw_encode [ptr [count] >> (16 + 4)] ;
@@ -331,7 +334,7 @@ i2alaw_array (int *ptr, int count, unsigned char *buffer)
 } /* i2alaw_array */
 
 static inline void
-f2alaw_array (float *ptr, int count, unsigned char *buffer, float normfact)
+f2alaw_array (const float *ptr, int count, unsigned char *buffer, float normfact)
 {	while (--count >= 0)
 	{	if (ptr [count] >= 0)
 			buffer [count] = alaw_encode [lrintf (normfact * ptr [count])] ;
@@ -341,7 +344,7 @@ f2alaw_array (float *ptr, int count, unsigned char *buffer, float normfact)
 } /* f2alaw_array */
 
 static inline void
-d2alaw_array (double *ptr, int count, unsigned char *buffer, double normfact)
+d2alaw_array (const double *ptr, int count, unsigned char *buffer, double normfact)
 {	while (--count >= 0)
 	{	if (ptr [count] >= 0)
 			buffer [count] = alaw_encode [lrint (normfact * ptr [count])] ;
@@ -446,7 +449,7 @@ alaw_read_alaw2d (SF_PRIVATE *psf, double *ptr, sf_count_t len)
 */
 
 static sf_count_t
-alaw_write_s2alaw	(SF_PRIVATE *psf, short *ptr, sf_count_t len)
+alaw_write_s2alaw	(SF_PRIVATE *psf, const short *ptr, sf_count_t len)
 {	int			bufferlen, writecount ;
 	sf_count_t	total = 0 ;
 
@@ -467,7 +470,7 @@ alaw_write_s2alaw	(SF_PRIVATE *psf, short *ptr, sf_count_t len)
 } /* alaw_write_s2alaw */
 
 static sf_count_t
-alaw_write_i2alaw	(SF_PRIVATE *psf, int *ptr, sf_count_t len)
+alaw_write_i2alaw	(SF_PRIVATE *psf, const int *ptr, sf_count_t len)
 {	int			bufferlen, writecount ;
 	sf_count_t	total = 0 ;
 
@@ -488,7 +491,7 @@ alaw_write_i2alaw	(SF_PRIVATE *psf, int *ptr, sf_count_t len)
 } /* alaw_write_i2alaw */
 
 static sf_count_t
-alaw_write_f2alaw	(SF_PRIVATE *psf, float *ptr, sf_count_t len)
+alaw_write_f2alaw	(SF_PRIVATE *psf, const float *ptr, sf_count_t len)
 {	int			bufferlen, writecount ;
 	sf_count_t	total = 0 ;
 	float	normfact ;
@@ -512,7 +515,7 @@ alaw_write_f2alaw	(SF_PRIVATE *psf, float *ptr, sf_count_t len)
 } /* alaw_write_f2alaw */
 
 static sf_count_t
-alaw_write_d2alaw	(SF_PRIVATE *psf, double *ptr, sf_count_t len)
+alaw_write_d2alaw	(SF_PRIVATE *psf, const double *ptr, sf_count_t len)
 {	int			bufferlen, writecount ;
 	sf_count_t	total = 0 ;
 	double	normfact ;
@@ -535,10 +538,3 @@ alaw_write_d2alaw	(SF_PRIVATE *psf, double *ptr, sf_count_t len)
 	return total ;
 } /* alaw_write_d2alaw */
 
-/*
-** Do not edit or modify anything in this comment block.
-** The arch-tag line is a file identity tag for the GNU Arch 
-** revision control system.
-**
-** arch-tag: 289ccfc2-42a6-4f1f-a29f-4dcc9bfa8752
-*/
